pitchtools.NumberedPitch
========================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch

.. autoclass:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.accidental
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.accidental_spelling
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.alteration_in_semitones
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.apply_accidental
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.invert
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_diatonic_pitch_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_diatonic_pitch_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_carrier
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_class_octave_number_string
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.multiply
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.named_pitch
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.named_pitch_class
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.numbered_pitch
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.numbered_pitch_class
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.octave
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.octave_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_octave_label
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_name
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_number
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.transpose
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__abs__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__add__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__eq__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__float__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__format__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__ge__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__gt__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__hash__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__illustrate__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__int__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__le__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__lt__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__ne__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__neg__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__repr__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__str__
      ~abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__sub__

Bases
-----

- :py:class:`pitchtools.Pitch <abjad.tools.pitchtools.Pitch.Pitch>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.accidental
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.accidental_spelling
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.alteration_in_semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_class_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_class_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.diatonic_pitch_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.named_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.named_pitch_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.numbered_pitch
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.numbered_pitch_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.octave
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.octave_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_class_octave_label
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.pitch_number
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.apply_accidental
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.transpose
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_diatonic_pitch_name
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_diatonic_pitch_number
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_carrier
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_class_octave_number_string
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_name
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.is_pitch_number
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__illustrate__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitch.NumberedPitch.__sub__
   :noindex:
